Struct BigInt

pub struct BigInt(/* private fields */);
BigInt wrapper

This type may not be necessary, but it is used to get around the orphan rule for implementing async-graphql and sqlx traits.

Implementations

Source

impl BigInt

pub fn new(inner: BIO) -> Self

pub fn into_inner(self) -> BIO

pub fn as_inner(&self) -> &BIO

Source

impl BigInt

pub fn abs(&self) -> Self

pub fn sign(&self) -> Sign

pub fn to_bytes_le(&self) -> (Sign, Vec<u8>)

pub fn to_bytes_be(&self) -> (Sign, Vec<u8>)

pub fn checked_add(&self, v: &Self) -> Option<Self>

pub fn checked_sub(&self, v: &Self) -> Option<Self>

pub fn checked_mul(&self, v: &Self) -> Option<Self>

pub fn checked_div(&self, v: &Self) -> Option<Self>

pub fn from_bytes_be(sign: impl Into<Sign>, bytes: &[u8]) -> Self

pub fn from_bytes_le(sign: impl Into<Sign>, bytes: &[u8]) -> Self

pub fn from_signed_bytes_be(bytes: &[u8]) -> Self

pub fn from_signed_bytes_le(bytes: &[u8]) -> Self

pub fn from_radix_be( sign: impl Into<Sign>, buf: &[u8], radix: u32, ) -> Option<Self>

pub fn from_radix_le( sign: impl Into<Sign>, buf: &[u8], radix: u32, ) -> Option<Self>

pub fn from_slice(sign: impl Into<Sign>, slice: &[u32]) -> Self