pub struct LatestBlock<B: BlockNumber> { /* private fields */ }Expand description
Used in Network::wait_for_latest_block
Represents the latest block available in the blockchain, along with a block to rollback to if a fork was detected.
Implementations
Sourceimpl<B: BlockNumber> LatestBlock<B>
impl<B: BlockNumber> LatestBlock<B>
pub fn new(advance_to: B) -> Self
pub fn with_rollback(self, rollback_to: B) -> Self
pub fn advance_to(&self) -> B
pub fn rollback_to(&self) -> Option<B>