pub struct MetaEvent<C: Cidomap> { /* private fields */ }Expand description
Information about an event like the time it was created, where in the blockchain it was created the block it came from and information about the trigger that matched it
Implementations
Sourceimpl<C: Cidomap> MetaEvent<C>
impl<C: Cidomap> MetaEvent<C>
pub fn new( trigger: <C::Network as Network>::Trigger, timestamp: DateTime<Utc>, trigger_processing_order: u8, order: <C::Network as Network>::EventOrder, block: Arc<<C::Network as Network>::FullBlock>, ) -> Self
Sourcepub fn trigger(&self) -> &<C::Network as Network>::Trigger
pub fn trigger(&self) -> &<C::Network as Network>::Trigger
Returns the trigger that matched this event
Sourcepub fn block_number(&self) -> <C::Network as Network>::BlockNumber
pub fn block_number(&self) -> <C::Network as Network>::BlockNumber
Returns the block number of this event
Sourcepub fn event_order(&self) -> <C::Network as Network>::EventOrder
pub fn event_order(&self) -> <C::Network as Network>::EventOrder
Returns the event order of this event